@@ -840,7 +840,7 @@ def _delete_object(bucket, file_name):
     return s3_client.delete_object(Bucket=bucket, Key=file_name)
 
 
-def _list_objects(bucket, prefix, delimiter, max_keys, token):
+def _list_objects(bucket, prefix, delimiter, max_keys, token=''):
     return s3_client.list_objects_v2(
         Bucket=bucket,
         Delimiter=delimiter,
